# `narwhals.selectors`

The following selectors are all supported. In addition, just like in Polars, the following
set operations are supported:

- set intersection: `&`
- set union: `|`
- set difference: `-`
- complement: `~`

::: narwhals.selectors
    handler: python
    options:
      members:
        - boolean
        - by_dtype
        - categorical
        - numeric
        - string
      show_root_heading: false
      show_source: false
      show_bases: false
